@@ -9,7 +9,7 @@ from django.utils.timezone import now
 from django_fsm.signals import pre_transition, post_transition
 
 from .managers import StateLogManager
-from .utils import import_class_by_path
+from django.utils.module_loading import import_by_path
 
 
 class StateLog(models.Model):
@@ -31,7 +31,11 @@ class StateLog(models.Model):
             self.transition
         )
 
-backend = import_class_by_path(settings.DJANGO_FSM_LOG_STORAGE_METHOD)
-backend.setup_model(StateLog)
-pre_transition.connect(backend.pre_transition_callback)
-post_transition.connect(backend.post_transition_callback)
+try:
+    import django.apps
+except: # django < 1.7
+    backend = import_by_path(settings.DJANGO_FSM_LOG_STORAGE_METHOD)
+    backend.setup_model(StateLog)
+
+    pre_transition.connect(backend.pre_transition_callback)
+    post_transition.connect(backend.post_transition_callback)
